@@ -21,6 +21,7 @@
 #include <qdatetime.h>
 #include <qpixmap.h>
 #include <qfont.h>
+#include <qfontdatabase.h>
 #include <qrect.h>
 #include <qpoint.h>
 #include <qtimer.h>
@@ -102,21 +103,54 @@ void Kountdown::readSettings( int setting )
 	case 1:
 		config->setGroup( "HalfWay settings" );
 		break;
-	case 2:
-		config->setGroup( "Finish settings" );
-		break;
-	}
+  case 2:
+    config->setGroup( "Finish settings" );
+    break;
+  }
 
-	text = config->readEntry( "Text", i18n( "Default text, please setup the screensaver first" ));
-	backCol = config->readColorEntry( "BackCol", &Qt::black );
-	fontCol = config->readColorEntry( "FontCol", &Qt::blue );
-	font = config->readFontEntry( "Font" );
-	speed = config->readNumEntry( "Speed", 50 );
- 	textEffect = config->readNumEntry( "Text effect", 0 );
- 	repaint = listRepaint[textEffect];
+  text = config->readEntry( "Text", i18n( "Default text, please setup the screensaver first" ));
+  if ( config->readBoolEntry( "RandomBackCol", false ) )
+    backCol = randomColor();
+  else
+    backCol = config->readColorEntry( "BackCol", &Qt::black );
+  if ( config->readBoolEntry( "RandomFontCol", false ) )
+    fontCol = randomColor();
+  else
+    fontCol = config->readColorEntry( "FontCol", &Qt::blue );
+  if ( config->readBoolEntry( "RandomFont", false ) )
+    font = randomFont();
+  else
+    font = config->readFontEntry( "Font" );
+  speed = config->readNumEntry( "Speed", 50 );
+  textEffect = config->readNumEntry( "Text effect", 0 );
+  repaint = listRepaint[textEffect];
 
-	if ( setting > 0 ) // We have been called to change settings (not setting them)
-		kountdown();
+  if ( setting > 0 ) // We have been called to change settings (not setting them)
+    kountdown();
+}
+
+QFont Kountdown::randomFont()
+{
+  QFontDatabase fdb;
+
+  QStringList fam = fdb.families();
+  QString family( fam[ kapp->random() % fam.count() ] );
+
+  QStringList st = fdb.styles( family );
+  QString style( st[ kapp->random() % st.count() ] );
+
+  QValueList<int> si = fdb.pointSizes( family, style );
+  int size = si[ kapp->random() % si.count() ];
+
+  return fdb.font( family, style, size );
+}
+
+QColor Kountdown::randomColor()
+{
+  int r = kapp->random() % 255;
+  int g = kapp->random() % 255;
+  int b = kapp->random() % 255;
+  return QColor( r, g, b );
 }
 
 void Kountdown::kountdown()
