@@ -58,6 +58,8 @@ class Kountdown : public KScreenSaver
 	private:
 		void readGlobalSettings();
 		void kountdown();
+     QFont randomFont();
+     QColor randomColor();
 
 		// Settings, set after current setting (start, half, finish)
 		QColor backCol, fontCol;
