@@ -1,5 +1,5 @@
 /***************************************************************************
-                          main.cpp  -  description
+                          main.cpp  -  Starts the screensaver or screensaver setup
                              -------------------
     begin                : Sun Feb 10 09:52:20 CET 2002
     copyright            : (C) 2002 by Erik Johansson
@@ -18,13 +18,13 @@
 #include <klocale.h>
 
 #include "kountdown.h"
-#include "kountdownsetup.h"
+#include "setupdlg/setupdlg.h"
 
 // libkscreensaver interface
 extern "C"
 {
     const char *kss_applicationName = "kountdown.kss";
-    const char *kss_description = I18N_NOOP( "KountDown" );
+    const char *kss_description = I18N_NOOP( "KountDown, the screensaver that counts down to selected date" );
     const char *kss_version = VERSION;
 
     KScreenSaver *kss_create( WId id )
@@ -34,7 +34,6 @@ extern "C"
 
     QDialog *kss_setup()
     {
-        return new KountdownSetup();
+			return new SetupDlg();
     }
 }
-
